@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.24.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.25.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -143,9 +143,10 @@ sub configure {
     $self->add_plugins(
     qw/
         SchwartzRatio 
-    /,
-        'Test::UnusedVars',
-        'RunExtraTests',
+        Test::UnusedVars
+        Test::PAUSE::Permissions
+        RunExtraTests
+    /
     );
 
     if ( my $help_wanted = $arg->{help_wanted} ) {
@@ -183,7 +184,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.24.0
+version 0.25.0
 
 =head1 DESCRIPTION
 
@@ -274,6 +275,7 @@ his distributions. It's roughly equivalent to
 
     [RunExtraTests]
     [Test::UnusedVars]
+    [Test::PAUSE::Permisions]
 
     [DOAP]
     process_changes = 1
